#
# spec file for package headscale
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           headscale
Version:        0.25.0
Release:        1.1
Summary:        An open source, self-hosted implementation of the Tailscale control server
License:        BSD-3-Clause
URL:            https://headscale.net
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        headscale.sysusers
Source3:        headscale.tmpfs.conf
Source4:        headscale.systemd.service
Source5:        config-example.yaml
Source6:        derp-example.yaml
BuildRequires:  golang-packaging
BuildRequires:  sysuser-shadow
BuildRequires:  sysuser-tools
BuildRequires:  zstd
BuildRequires:  pkgconfig(systemd)
Suggests:       postgresql-server
Suggests:       wireguard-tools
%{?systemd_ordering}
%{?sysusers_requires}

%description
Headscale aims to implement a self-hosted, open source alternative to the
Tailscale control server. Headscale's goal is to provide self-hosters and
hobbyists with an open-source server they can use for their projects and labs.
It implements a narrow scope, a single Tailnet, suitable for a personal use, or
a small open-source organisation.

%prep
%autosetup -a1

%build
go build -v -buildmode=pie -mod=vendor -tags "ts2019" -ldflags "-X github.com/juanfont/headscale/cmd/headscale/cli.Version=%{version}" ./cmd/headscale

%sysusers_generate_pre %{SOURCE2} %{name} %{name}.conf

%install
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
mkdir -p %{buildroot}%{_sharedstatedir}/%{name}
install -D -m 755 %{name} %{buildroot}%{_bindir}/%{name}
install -D -m 644 %{SOURCE2} %{buildroot}%{_sysusersdir}/%{name}.conf
install -D -m 644 %{SOURCE3} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -D -m 644 %{SOURCE4} %{buildroot}%{_unitdir}/%{name}.service
%if 0%{?suse_version} == 1500
install -D -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/%{name}/config-example.yaml
install -D -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/%{name}/config-derp.yaml
%else
install -D -m 644 %{SOURCE5} %{buildroot}/%{_distconfdir}/%{name}/config-example.yaml
install -D -m 644 %{SOURCE6} %{buildroot}/%{_distconfdir}/%{name}/derp-example.yaml
%endif

%pre -f %{name}.pre
%service_add_pre %{name}.service

%post
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/%{name}
%dir %{_sysconfdir}/%{name}
%dir %{_sharedstatedir}/%{name}
%if 0%{?suse_version} == 1500
%{_sysconfdir}/%{name}
%else
%dir %{_distconfdir}/%{name}
%{_distconfdir}/%{name}/*
%endif
%{_sysusersdir}/%{name}.conf
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service

%changelog
* Thu Feb 13 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.25.0:
  BREAKING:
  * Authentication flow has been rewritten
  * Remove support for Tailscale clients older than 1.62 (Capability version 87)
  CHANGES:
  * oidc.map_legacy_users is now false by default
  * Print Tailscale version instead of capability versions for outdated nodes
  * Do not allow renaming of users from OIDC
  * Change minimum hostname length to 2
  * Fix migration error caused by nodes having invalid auth keys
  * Pre auth keys belonging to a user are no longer deleted with the user
  * Pre auth keys that are used by a node can no longer be deleted
  * Rehaul HTTP errors, return better status code and errors to users
* Fri Feb  7 2025 Richard Rahl <rrahl0@opensuse.org>
- update 0.24.3:
  * Fix migration error caused by nodes having invalid auth keys
  * Pre auth keys belonging to a user are no longer deleted with the user
  * Pre auth keys that are used by a node can no longer be deleted
- update to 0.24.2:
  * Fix issue where email and username being equal fails to match in Policy
  * Delete invalid routes before adding a NOT NULL constraint on node_id
- update to 0.24.1:
  * Fix migration issue with user table for PostgreSQL
  * Relax username validation to allow emails
  * Remove invalid routes and add stronger constraints for routes to avoid API panic
  * Fix panic when derp.update_frequency is 0
- update to 0.24.0:
  BREAKING:
  * Remove dns.use_username_in_magic_dns configuration option
  * Having usernames in magic DNS is no longer possible.
  * Remove versions older than 1.56
  * Clean up old code required by old versions
  * If you depend on a Headscale Web UI, you should wait with this update until
    the UI have been updated to match the new API.
  * GET /api/v1/user/{name} and GetUser have been removed in favour of
    ListUsers with an ID parameter
  * RenameUser and DeleteUser now require an ID instead of a name.
  CHANGES:
  * Improved compatibility of built-in DERP server with clients connecting over WebSocket
  * Allow nodes to use SSH agent forwarding
  * Fixed processing of fields in post request in MoveNode rpc
  * Added conversion of 'Hostname' to 'givenName' in a node with FQDN rules applied
  * Fixed updating of hostname and givenName when it is updated in HostInfo
  * Fixed missing stable-debug container tag
  * Loosened up server_url and base_domain check. It was overly strict in some cases
  * CLI for managing users now accepts --identifier in addition to --name,
    usage of --identifier is recommended
  * Add dns.extra_records_path configuration option
  * Support client verify for DERP
  * Add PKCE Verifier for OIDC
* Thu Jan  2 2025 Marcus Rueckert <mrueckert@suse.de>
- Fix the system integration
  - actually build and use the sysuser pre snippet so that the user
    is created before tmpfiles.d tries to create files
- no longer break debugsymbols for the binary (remove -s -w)
- use systemd macros for paths
- ensure proper requires/ordering for sysuser/systemd
* Wed Sep 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.23.0:
  * Code reorganisation, a lot of code has moved
  * Change the structure of database configuration, see config-example.yaml
  - Old structure has been remove and the configuration must be converted
  - Adds additional configuration for PostgreSQL for setting max open,
    idle connection and idle connection lifetime
  * API: Machine is now Node
  * Remove support for older Tailscale clients (supported >=1.42)
  * Headscale checks that at least one DERP is defined at start
  * Embedded DERP server requires a private key
  * Prefixes are now defined per v4 and v6 range
  * MagicDNS domains no longer contain usernames
  * YAML files are no longer supported for headscale policy (use HuJSON)
  * DNS configuration has been restructured
  * Use versioned migrations
  * Make the OIDC callback page better
  * SSH support
  * State management has been improved
  * Use error group handling to ensure tests actually pass
  * Fix hang on SIGTERM
  * Send logs to stderr by default
  * Fix TS-2023-006 security UPnP issue
  * Turn off gRPC logging
  * Added the possibility to manually create a DERP-map entry
  * Add support for deleting api keys
  * Add command to backfill IP addresses for nodes missing IPs from configured prefixes
  * Log available update as warning
  * Add autogroup:internet to Policy
  * Restore foreign keys and add constraints
  * Make registration page easier to use on mobile devices
  * Make write-ahead-log default on and configurable for SQLite
  * Add APIs for managing headscale policy
  * Fix for registering nodes using preauthkeys when running
    on a postgres database in a non-UTC timezone
  * Make sure integration tests cover postgres for all scenarios
  * CLI commands (all except serve) only requires minimal configuration
  * CLI results are now concistently sent to stdout and errors to stderr
  * Fix issue where shutting down headscale would hang
  * add shutdown that asserts if headscale had panics
* Thu Apr 18 2024 Richard Rahl <rrahl0@disroot.org>
- remove CAP_CHOWN from systemd unit file, as it's unneeded
* Wed Dec 20 2023 Richard Rahl <rrahl0@proton.me>
- initial packaging
